zot_get_creator_types: Find and show all valid creator types

View source: R/read.R

zot_get_creator_typesR Documentation

Find and show all valid creator types

Description

Find and show all valid creator types

Usage

zot_get_creator_types(item_type = "book", cache = TRUE, locale = NULL)

Arguments

cache

Logical, defaults to TRUE. If TRUE, it stores the list of valid item types in a "zot_cache" folder in the current working directory.

locale

Defaults to English. If given, it should correspond to a language code such as "it" or "fr-FR"

Value

A list including all valid creator types for given item type.

Examples

## Not run: 
creator_types <- zot_get_creator_types()

## End(Not run)

giocomai/zoteror documentation built on April 12, 2025, 12:48 p.m.