| zot_get_creator_types | R Documentation |
Find and show all valid creator types
zot_get_creator_types(item_type = "book", cache = TRUE, locale = NULL)
cache |
Logical, defaults to TRUE. If TRUE, it stores the list of valid item types in a "zot_cache" folder in the current working directory. |
locale |
Defaults to English. If given, it should correspond to a language code such as "it" or "fr-FR" |
A list including all valid creator types for given item type.
## Not run:
creator_types <- zot_get_creator_types()
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.